% Barman Manual
% EnterpriseDB UK Limited
% June 12, 2024 (3.10.1)

**Barman** (Backup and Recovery Manager) is an open-source administration tool for disaster recovery of PostgreSQL servers written in Python. It allows your organisation to perform remote backups of multiple servers in business critical environments to reduce risk and help DBAs during the recovery phase.

[Barman][11] is distributed under GNU GPL 3 and maintained by [EnterpriseDB][13], a platinum sponsor of the [PostgreSQL project][31].

> **IMPORTANT:** \newline
> This manual assumes that you are familiar with theoretical disaster
> recovery concepts, and that you have a grasp of PostgreSQL fundamentals in
> terms of physical backup and disaster recovery. See section _"Before you start"_ below for details.
